==> haskell-parsers-0.12.7-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-parsers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: parsers
version: 0.12.7
id: parsers-0.12.7-C34JrySfMrGGlqNn6MwWT6
key: parsers-0.12.7-C34JrySfMrGGlqNn6MwWT6
license: BSD3
copyright: Copyright (C) 2010-2013 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/parsers/
synopsis: Parsing combinators
description:
    This library provides convenient combinators for working with and building parsing combinator libraries.
    .
    Given a few simple instances, e.g. for the class '\''Text.Parser.Combinators.Parsing'\'' in "Text.Parser.Combinators.Parsing" you
    get access to a large number of canned definitions. Instances exist for the parsers provided by @parsec@,
    @attoparsec@ and base’s "Text.Read".
category: Text, Parsing
author: Edward A. Kmett
exposed: True
indefinite: False
exposed-modules:
    Text.Parser.Char Text.Parser.Combinators Text.Parser.Expression
    Text.Parser.LookAhead Text.Parser.Permutation Text.Parser.Token
    Text.Parser.Token.Highlight Text.Parser.Token.Style
abi: e3be2d1f5e848de17c34348318e68634
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/parsers-0.12.7
library-dirs: /usr/lib/ghc-8.2.1/site-local/parsers-0.12.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/parsers-0.12.7
hs-libraries: HSparsers-0.12.7-C34JrySfMrGGlqNn6MwWT6
depends:
    base-4.10.0.0 base-orphans-0.6-9iPDLrUqQ5yHb9fb9OUZ9L
    charset-0.3.7.1-GeUGw0oSpvTDliiE1Z6Y7i containers-0.5.10.2
    semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP
    parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh
    attoparsec-0.13.2.0-KKDeQTJJuS9ICqGr2jqA4j
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz transformers-0.5.2.0
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
    scientific-0.3.5.1-imIXdjJRiA7LRtcu2MlFY
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             base-orphans-0.6-9iPDLrUqQ5yHb9fb9OUZ9L=80bc3cbc1a27ff088178ac694da5ed41
             charset-0.3.7.1-GeUGw0oSpvTDliiE1Z6Y7i=1ba0929cc101be3a5f1a5cd31982186d
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP=aad58cc65045b8e62f1806217258d930
             parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh=da03630454c215de5f3965e7b0f0e5da
             attoparsec-0.13.2.0-KKDeQTJJuS9ICqGr2jqA4j=408c5a9ef40ae69c083ed9d4aba83592
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             scientific-0.3.5.1-imIXdjJRiA7LRtcu2MlFY=147f92d1044da8ff4805281d8437c52f
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=7d7e1f3460b904c0be93ffa55855f4d0
haddock-interfaces: /usr/share/doc/haskell-parsers/html/parsers.haddock
haddock-html: /usr/share/doc/haskell-parsers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-parsers-0.12.7-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-parsers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: parsers
version: 0.12.7
id: parsers-0.12.7-1kfASGSbUOaHyymSJg92ek
key: parsers-0.12.7-1kfASGSbUOaHyymSJg92ek
license: BSD3
copyright: Copyright (C) 2010-2013 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/parsers/
synopsis: Parsing combinators
description:
    This library provides convenient combinators for working with and building parsing combinator libraries.
    .
    Given a few simple instances, e.g. for the class '\''Text.Parser.Combinators.Parsing'\'' in "Text.Parser.Combinators.Parsing" you
    get access to a large number of canned definitions. Instances exist for the parsers provided by @parsec@,
    @attoparsec@ and base’s "Text.Read".
category: Text, Parsing
author: Edward A. Kmett
exposed: True
indefinite: False
exposed-modules:
    Text.Parser.Char Text.Parser.Combinators Text.Parser.Expression
    Text.Parser.LookAhead Text.Parser.Permutation Text.Parser.Token
    Text.Parser.Token.Highlight Text.Parser.Token.Style
abi: 28f5d89af564c00015ae8eb2097c2ac7
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/parsers-0.12.7
library-dirs: /usr/lib/ghc-8.2.1/site-local/parsers-0.12.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/parsers-0.12.7
hs-libraries: HSparsers-0.12.7-1kfASGSbUOaHyymSJg92ek
depends:
    base-4.10.0.0 base-orphans-0.6-9iPDLrUqQ5yHb9fb9OUZ9L
    charset-0.3.7.1-GeUGw0oSpvTDliiE1Z6Y7i containers-0.5.10.2
    semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP
    parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh
    attoparsec-0.13.2.0-CjTw1SIXl7j4WJB8EsmBPm
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz transformers-0.5.2.0
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
    scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             base-orphans-0.6-9iPDLrUqQ5yHb9fb9OUZ9L=80bc3cbc1a27ff088178ac694da5ed41
             charset-0.3.7.1-GeUGw0oSpvTDliiE1Z6Y7i=1ba0929cc101be3a5f1a5cd31982186d
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP=aad58cc65045b8e62f1806217258d930
             parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh=da03630454c215de5f3965e7b0f0e5da
             attoparsec-0.13.2.0-CjTw1SIXl7j4WJB8EsmBPm=abc33533d9d12ab781226d56fe2dc420
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q=a0445f54fa186d288e1223c9f60f5307
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=7d7e1f3460b904c0be93ffa55855f4d0
haddock-interfaces: /usr/share/doc/haskell-parsers/html/parsers.haddock
haddock-html: /usr/share/doc/haskell-parsers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
